#!/bin/bash
# Install script for MeasureJ2X
#   check that Java is installed
#   setup serial ports
#
# Copyright (c) 2012. VoorTech Consulting - ProjectJ2X.  All Rights Reserved.
# Author: Nancy Voorhis (nancyv@voortech.com)
# ProjectJ2X info: http://www.voortech.com/projectj2x
#

####### determine if Java is installed and which version

echo "Checking Java runtime (JRE) requirement..."
echo

javaVersionMin="1.5.0"
# versions are 1.6.0_nn so this will encompass all 1.6.0 updates
javaVersionMax="1.6.1"

if [ `type -p java` ]; then
    javaExe=java
elif [[ -n "$JAVA_HOME" ]] && [[ -x "$JAVA_HOME/bin/java" ]];  then
    javaExe="$JAVA_HOME/bin/java"
else
    echo "Sorry, required Java runtime (JRE) does not appear to be installed. "
    echo "This must be corrected before MeasureJ2X will be able to run."
    echo
    echo "A JRE can be downloaded from java.com or by using your platform's native package system (ie 'pkg' for Debian/Ubuntu 'rpm' for Redhat).  JRE version required is >= $javaVersionMin."
    echo "If JRE is installed then it must appear on the executable path or the JAVA_HOME must be set for this user."
fi

if [ "$javaExe" ]; then
    version=$("$javaExe" -version 2>&1 | awk -F '"' '/version/ {print $2}')

    if [[ "$version" < "$javaVersionMin" ]]; then
	echo "The Java runtime (JRE) version found is not current enough ($version)"
	echo "JRE version required is $javaVersionMin or greater."
	echo "If a proper version of JRE is installed then it must appear on the executable path JAVA_HOME must be set for this user."
    else 
	if [[ "$version" > "$javaVersionMax" ]]; then
	    echo "***Warning: the Java runtime (JRE) version found [$version] is greater"
            echo "   than the latest version that MeasureJ2X has been fully tested with."
	    echo "   If you experience problems please install a JRE with version >= $javaVersionMin and <= $javaVersionMax."
	    echo "   If a proper version of JRE is installed then it must appear on the executable path or JAVA_HOME must be set for this user."
	    echo
	fi
	echo "Using Java runtime (JRE) as required by MeasureJ2X ($javaExe V $version)."
	echo "Please note future upgrades of the Java runtime (JRE) may affect MeasureJ2X."
    fi
fi

#################################
echo
echo "Checking serial ports..."
echo "If you are using a USB-serial adapter, please plug it in now - (enter/return) when ready> "
read usb

portFile="serialPorts"
serialPorts=""  
#  traditional serial ports /dev/ttySn  and USB-serial ports /dev/ttyUSBn
for port in `dmesg | egrep -o 'serial.*ttyS.|ttyUSB.' | egrep -o 'ttyU?SB?[0-9]' `;
do
    found=`echo $serialPorts | grep $port `
    if [ -z "$found" ] ; then
	if [ -z $serialPorts ]; then
	    serialPorts="/dev/$port"
	else
	    serialPorts="$serialPorts:/dev/$port"
	fi
    fi
done

if [ -n "$serialPorts" ] ;
then
    echo "The following serial ports were found: $serialPorts"
else
    echo "No serial ports were automagically found.  You will need to manually enter them."
fi

port2=""
echo "Enter any additional ports now (ie /dev/ttyUSB1) - blank (enter/return) when done> "
while  read port2
do 
    if [ -n "$port2" ] ; 
    then
	if [ -z $serialPorts ]; then
	    serialPorts="$port2"
	else
	    serialPorts="$serialPorts:$port2"
	fi
	port2=""
	echo "Enter any additional ports now (ie /dev/ttyUSB1) - blank(ret) when done:"
    else 
	break
    fi
done

echo "MeasureJ2X will use the following serial ports: "
echo "$serialPorts"

echo $serialPorts | cat > $portFile

#################################
# setup runMeasureJ2X.sh

runScript="runMeasureJ2X.sh"
install_dir=`pwd`
sed "s#MJ2X_HOME=#MJ2X_HOME=\"$install_dir\"#" $runScript.dist > $runScript
chmod 755 $runScript
if [ ! -e ~/Desktop/MeasureJ2X ] ; then
    ln -s $install_dir/runMeasureJ2X.sh ~/Desktop/MeasureJ2X
fi
echo
echo "The following command can be used to run MeasureJ2X from anywhere "
echo "or to create a launcher in your desktop gui (ie GNOME):"
echo "$install_dir/runMeasureJ2X.sh"
echo
echo "You may run MeasureJ2X using the shortcut that has been placed on your desktop:"
echo "MeasureJ2X"

echo
